import asyncio

from wiopy.AsyncWIO import AsyncWalmartIO


async def main():
    wiopy = AsyncWalmartIO(
        private_key_version="1",
        private_key_filename="./WM_IO_private_key.pem",
        consumer_id="5be6e783-5182-4c87-9238-40def66f5e58",
        publisherId="3187763",
    )

    # Catalog Product
    print("<-----Catalog Product ----->")
    data = await wiopy.catalog_product(category="3944", maxId="8342714")
    print(data.response_handler.payload.keys())
    print("\n\n\n\n")

    # Post Browsed Products
    print("<-----Post Browsed Products----->")
    data = await wiopy.post_browsed_products("54518466")
    print(data)
    print("\n\n\n\n")

    # Product lookup
    print("<-----Product lookup----->")
    data = await wiopy.product_lookup("33093101, 54518466, 516833054")
    for item in data:
        print(item)
    print("\n\n\n\n")

    # Bulk product lookup
    print("<-----Bulk Product lookup----->")
    data = wiopy.bulk_product_lookup("33093101, 54518466, 516833054", amount=1)
    async for items in data:
        for item in items:
            print(item)
        print("Next chunk")
    print("\n\n\n\n")

    # Product Recommendation
    print("<-----Product Recommendation----->")
    data = await wiopy.product_recommendation("54518466")
    print(data)
    print("\n\n\n\n")
    # Reviews
    print("<-----Reviews----->")
    data = await wiopy.reviews("33093101")
    print(data.reviewStatistics)
    print("\n\n\n\n")

    # Search
    print("<-----Search----->")
    data = await wiopy.search("tv", categoryId="3944", sort="price", order="ascending")
    print(data.totalResults)
    data = await wiopy.search("tv", filter="brand:Samsung")
    print(data["facets"])
    print("\n\n\n\n")

    # Stores
    print("<-----Stores----->")
    data = await wiopy.stores(lat=29.735577, lon=-95.511747)
    print(data[0])
    print("\n\n\n\n")

    # Taxonomy
    print("<-----Taxonomy----->")
    data = await wiopy.taxonomy()
    print(data)
    print("\n\n\n\n")

    # Trending
    print("<-----Trending----->")
    data = await wiopy.trending()
    print(data)
    print("\n\n\n\n")


# Simple tests
if __name__ == "__main__":
    asyncio.run(main())
